package com.srs.workstudy.mapper;

import java.util.List;

import com.srs.workstudy.domain.QgzxPost;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;

/**
 * 勤工助学岗位Mapper接口
 *
 * @author srs
 * @date 2024-05-30
 */
@Mapper
public interface QgzxPostMapper extends BaseMapper<QgzxPost> {



    public List<QgzxPost> listView(QgzxPost param);


    /**
     * 查询勤工助学岗位
     *
     * @param id 勤工助学岗位主键
     * @return 勤工助学岗位
     */
    public QgzxPost selectQgzxPostById(Long id);

    /**
     * 查询勤工助学岗位列表
     *
     * @param qgzxPost 勤工助学岗位
     * @return 勤工助学岗位集合
     */
    List<QgzxPost> selectQgzxPostList(QgzxPost qgzxPost);

    /**
     * 新增勤工助学岗位
     *
     * @param qgzxPost 勤工助学岗位
     * @return 结果
     */
    int insertQgzxPost(QgzxPost qgzxPost);

    /**
     * 修改勤工助学岗位
     *
     * @param qgzxPost 勤工助学岗位
     * @return 结果
     */
    int updateQgzxPost(QgzxPost qgzxPost);

    /**
     * 删除勤工助学岗位
     *
     * @param id 勤工助学岗位主键
     * @return 结果
     */
    int deleteQgzxPostById(Long id);

    /**
     * 批量删除勤工助学岗位
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteQgzxPostByIds(Long[] ids);
}
